@@ -16,7 +16,7 @@ cfgUnknown = "espeakcaller_unknown.conf"
 cfgBlocked = "espeakcaller_blocked.conf"
 cfgGlobal = "espeakcaller_global.conf"
 _HEADPHONE_SYS = "/sys/devices/platform/gpio-switch/headphone/state"
- 
+
 class eSpeakCallerDaemon():
     def __init__(self):
         LogPath = os.path.expanduser(cfgFileLoc + "espeakcaller.log")
@@ -191,6 +191,8 @@ class eSpeakCallerDaemon():
                 lines = pdFile.readlines()
                 pdFile.close()
                 
+		global silenceSpeakers
+
                 for line in lines:
                     line = line.strip()
                     if line.startswith("eSpeak:"):
@@ -242,6 +244,7 @@ class eSpeakCallerDaemon():
             
             if dest == "org.maemo.Playback.Manager" and mem == "RequestState":
                 if args[1] == "Stop":
+		    global eSpeakProc
                     #print "Stop event!"
                     if self.eSpeakProc != 0:   
                         self.Log("Mute pressed. Killing espeak.")
